<?php

declare(strict_types=1);

namespace Auth0\WordPress\Http\Message;

use Psr\Http\Message\{RequestInterface, StreamInterface, UriInterface};

final class Request implements RequestInterface
{
    use MessageTrait;

    use RequestTrait;

    public function __construct(
        string $method,
        string | UriInterface $uri,
        array $headers = [],
        string | StreamInterface | null $body = null,
        string $version = '1.1',
    ) {
        if (! ($uri instanceof UriInterface)) {
            $uri = new Uri($uri);
        }

        $this->method = strtoupper($method);
        $this->uri = $uri;
        $this->setHeaders($headers);
        $this->protocol = $version;

        if (! $this->hasHeader('Host')) {
            $this->updateHostFromUri();
        }

        if ('' === $body) {
            return;
        }

        if (null === $body) {
            return;
        }

        $this->stream = Stream::create($body);
    }
}
